#!/bin/bash

USR="gtmadmin"
GRP="gtmgroup"
PTH="/opt/air-gtm"
DB="/srv/soi"
PACKAGES="cmake libelf-dev zlib1g-dev libncurses5-dev tcsh libicu-dev libgpgme-dev libgpg-error-dev libgcrypt20-dev"
D=`pwd`


Echo() {
    echo -e "\n\n\t\t$*\n\n"
}

Exit() {
    echo
    exit 1
}


if [ $USER != 'root' ]; then
    Echo "Запустите скрипт от имени root!"
    Exit
fi

if ! [[ `uname -v` =~ "deb9" ]]; then
    Echo "Скрипт предназначен для работы в ОС Debian 9"
    Exit
fi

if ! [ -d ${DB} ]; then
    mkdir ${DB}
fi

while [ -n "$1" ]; do
    case "$1" in
        --group)
            GRP=${2}
            shift;;
        --user)
            USR=${2}
            shift;;
        --installdir)
            PTH=${2};;
        *)
            Echo "Неизвестный параметр: ${1}"
            Exit;;
    esac
    shift
done

apt install -y ${PACKAGES}

if [ `grep -c ${GRP} /etc/group` -eq 0 ]; then
    groupadd ${GRP}
else
    echo "Группа ${GRP} уже существует"
fi

if [ `grep -c ${USR} /etc/passwd` -eq 0 ]; then
    useradd -m -d /home/${USR} -G ${GRP} -s /bin/bash -c "GT.M Administrator" ${USR}
    echo -e "${USR}\n${USR}" | passwd ${USR}
    trap  int quit
    echo "
##################################################
trap  int quit
export gtm_nocenable=1
export gtm_dist=${PTH}
export gtm_retention=10
export gtm_tmp=/tmp
export gtm_tprestart_log_delta=3
if [ -d ${DB} ]; then 
    export gtmgbldir=${DB}/conf.gld
    export gtmroutines=\"${DB}/o(${DB}/r) ${PTH} ${PTH}/libgtmshr.so\"
    export TERM=vt220
fi 
##################################################
    " >> /home/${USR}/.profile
    echo "
##################################################
alias gtm=\"${PTH}/mumps -dir\"
alias dse=\"${PTH}/dse\"
alias gde=\"${PTH}/mumps -run GDE\"
alias lke=\"${PTH}/lke\"
alias mupip=\"${PTH}/mupip\"
##################################################
    " >> /home/${USR}/.bashrc
    Echo "Создан пользователь ${USR} с паролем ${USR}"
    Echo "Не забудте сменить пароль!!!"
    
else
    echo "Пользователь ${GRP} уже существует"
fi

export PTH

mkdir air-gtm
cd air-gtm

if [ $? -ne 0 ]; then
    Echo "Не удалость создать каталог air-gtm"
    exit 1
else
    cmake ..
fi

if [ $? -ne 0 ]; then
    Echo "CMAKE Fail"
    exit 1
else
    make
fi

if [ $? -ne 0 ]; then
    Echo "MAKE Fail"
    exit 1
else
    make install
fi

if [ $? -ne 0 ]; then
    Echo "MAKE INSTALL Fail"
    exit 1
else
    make clean
fi

if [ -d ${PTH} ]; then
    cd ${PTH}
    chown ${USR}:${GRP} *
    chown root gtmsecshrdir gtmsecshr gtcm_run
    chmod 0444 *.o *.m *.dat *.h *.txt COPYING
    chmod 0555 *.so plugin dse ftok geteuid gtcm_gnp_server gtcm_pkdisp \
            gtcm_play gtcm_server gtcm_shmclean lke mumps mupip semstat2
    chmod 0500 gtmsecshrdir
    chmod 4555 gtmsecshr
else
    Echo "${PTH} не существует!"
fi

for sdir in g o r j tmp; do
    if ! [ -d $DB/${sdir} ]; then
        mkdir $DB/${sdir}
    fi
done
chown -r ${USR}:${GRP} ${DB}
chmod -r 750 ${DB}

echo "
template -region -key=511 -record_size=32768
template -segment -BL=4096 -AL=5000 -EX=10000 -L=40 -G=1024
change -segment DEFAULT -AC=BG -BL=4096 -AL=5000 -EX=10000 -L=40 -G=1024 -F=${DB}/g/task.dat
add -segment TEMP -AC=BG -F=${DB}/tmp/temp.dat
add -segment WORK -AC=BG -F=${DB}/g/work.dat
add -segment DATA -AC=BG -F=${DB}/g/data.dat
change -region DEFAULT -record_size=32768 -key_size=511 -dyn=DEFAULT -nojournal
add -region TEMP -dyn=TEMP -nojournal
add -region WORK -dyn=WORK -nojournal
add -region DATA -journal=(before,file=\"${DB}/j/data.mjl\") -dyn=DATA
add -name tmp* -region=TEMP
add -name TMP* -region=TEMP
add -name temp* -region=TEMP
add -name TEMP* -region=TEMP
add -name F -region=WORK
add -name B -region=DATA
add -name D -region=DATA
add -name K -region=DATA
" > /home/${USR}/main.gde

echo "${USR}"

su ${USR} -c "$D/usrscr.sh"
